@@ -20,12 +20,15 @@
 
 #include <util/util.hpp>
 #include <QDialog>
+#include <QPointer>
 #include <memory>
 #include <string>
 
 #include <libff/ff-util.h>
 
-#include <obs.h>
+#include <obs.hpp>
+
+#include "auth-base.hpp"
 
 class OBSBasic;
 class QAbstractButton;
@@ -37,6 +40,10 @@ class OBSHotkeyWidget;
 
 #include "ui_OBSBasicSettings.h"
 
+#define VOLUME_METER_DECAY_FAST 23.53
+#define VOLUME_METER_DECAY_MEDIUM 11.76
+#define VOLUME_METER_DECAY_SLOW 8.57
+
 class SilentUpdateCheckBox : public QCheckBox {
 	Q_OBJECT
 
@@ -61,8 +68,7 @@ public slots:
 	}
 };
 
-class OBSFFDeleter
-{
+class OBSFFDeleter {
 public:
 	void operator()(const ff_format_desc *format)
 	{
@@ -73,19 +79,33 @@ public:
 		ff_codec_desc_free(codec);
 	}
 };
-using OBSFFCodecDesc = std::unique_ptr<const ff_codec_desc,
-		OBSFFDeleter>;
-using OBSFFFormatDesc = std::unique_ptr<const ff_format_desc,
-		OBSFFDeleter>;
+using OBSFFCodecDesc = std::unique_ptr<const ff_codec_desc, OBSFFDeleter>;
+using OBSFFFormatDesc = std::unique_ptr<const ff_format_desc, OBSFFDeleter>;
 
 class OBSBasicSettings : public QDialog {
 	Q_OBJECT
+	Q_PROPERTY(QIcon generalIcon READ GetGeneralIcon WRITE SetGeneralIcon
+			   DESIGNABLE true)
+	Q_PROPERTY(QIcon streamIcon READ GetStreamIcon WRITE SetStreamIcon
+			   DESIGNABLE true)
+	Q_PROPERTY(QIcon outputIcon READ GetOutputIcon WRITE SetOutputIcon
+			   DESIGNABLE true)
+	Q_PROPERTY(QIcon audioIcon READ GetAudioIcon WRITE SetAudioIcon
+			   DESIGNABLE true)
+	Q_PROPERTY(QIcon videoIcon READ GetVideoIcon WRITE SetVideoIcon
+			   DESIGNABLE true)
+	Q_PROPERTY(QIcon hotkeysIcon READ GetHotkeysIcon WRITE SetHotkeysIcon
+			   DESIGNABLE true)
+	Q_PROPERTY(QIcon advancedIcon READ GetAdvancedIcon WRITE SetAdvancedIcon
+			   DESIGNABLE true)
 
 private:
 	OBSBasic *main;
 
 	std::unique_ptr<Ui::OBSBasicSettings> ui;
 
+	std::shared_ptr<Auth> auth;
+
 	bool generalChanged = false;
 	bool stream1Changed = false;
 	bool outputsChanged = false;
@@ -93,11 +113,12 @@ private:
 	bool videoChanged = false;
 	bool hotkeysChanged = false;
 	bool advancedChanged = false;
-	int  pageIndex = 0;
+	int pageIndex = 0;
 	bool loading = true;
 	std::string savedTheme;
 
 	int lastSimpleRecQualityIdx = 0;
+	int lastChannelSetupIdx = 0;
 
 	OBSFFFormatDesc formats;
 
@@ -117,9 +138,9 @@ private:
 	QString curAdvRecordEncoder;
 
 	using AudioSource_t =
-		std::tuple<OBSWeakSource,
-			QPointer<QCheckBox>, QPointer<QSpinBox>,
-			QPointer<QCheckBox>, QPointer<QSpinBox>>;
+		std::tuple<OBSWeakSource, QPointer<QCheckBox>,
+			   QPointer<QSpinBox>, QPointer<QCheckBox>,
+			   QPointer<QSpinBox>>;
 	std::vector<AudioSource_t> audioSources;
 	std::vector<OBSSignal> audioSourceSignals;
 	OBSSignal sourceCreated;
@@ -133,24 +154,24 @@ private:
 	uint32_t outputCY = 0;
 
 	void SaveCombo(QComboBox *widget, const char *section,
-			const char *value);
+		       const char *value);
 	void SaveComboData(QComboBox *widget, const char *section,
-			const char *value);
+			   const char *value);
 	void SaveCheckBox(QAbstractButton *widget, const char *section,
-			const char *value, bool invert = false);
+			  const char *value, bool invert = false);
 	void SaveEdit(QLineEdit *widget, const char *section,
-			const char *value);
+		      const char *value);
 	void SaveSpinBox(QSpinBox *widget, const char *section,
-			const char *value);
+			 const char *value);
 	void SaveFormat(QComboBox *combo);
 	void SaveEncoder(QComboBox *combo, const char *section,
-			const char *value);
+			 const char *value);
 
 	inline bool Changed() const
 	{
 		return generalChanged || outputsChanged || stream1Changed ||
-			audioChanged || videoChanged || advancedChanged ||
-			hotkeysChanged;
+		       audioChanged || videoChanged || advancedChanged ||
+		       hotkeysChanged;
 	}
 
 	inline void EnableApplyButton(bool en)
@@ -163,10 +184,10 @@ private:
 		generalChanged = false;
 		stream1Changed = false;
 		outputsChanged = false;
-		audioChanged   = false;
-		videoChanged   = false;
+		audioChanged = false;
+		videoChanged = false;
 		hotkeysChanged = false;
-		advancedChanged= false;
+		advancedChanged = false;
 		EnableApplyButton(false);
 	}
 
@@ -180,7 +201,6 @@ private:
 
 	bool QueryChanges();
 
-	void LoadServiceTypes();
 	void LoadEncoderTypes();
 	void LoadColorRanges();
 	void LoadFormats();
@@ -191,17 +211,37 @@ private:
 	void LoadOutputSettings();
 	void LoadAudioSettings();
 	void LoadVideoSettings();
-	void LoadHotkeySettings(obs_hotkey_id ignoreKey=OBS_INVALID_HOTKEY_ID);
+	void
+	LoadHotkeySettings(obs_hotkey_id ignoreKey = OBS_INVALID_HOTKEY_ID);
 	void LoadAdvancedSettings();
 	void LoadSettings(bool changedOnly);
 
 	OBSPropertiesView *CreateEncoderPropertyView(const char *encoder,
-			const char *path, bool changed = false);
+						     const char *path,
+						     bool changed = false);
 
 	/* general */
 	void LoadLanguageList();
 	void LoadThemeList();
 
+	/* stream */
+	void InitStreamPage();
+	inline bool IsCustomService() const;
+	void LoadServices(bool showAll);
+	void OnOAuthStreamKeyConnected();
+	void OnAuthConnected();
+	QString lastService;
+private slots:
+	void UpdateServerList();
+	void UpdateKeyLink();
+	void on_show_clicked();
+	void on_authPwShow_clicked();
+	void on_connectAccount_clicked();
+	void on_disconnectAccount_clicked();
+	void on_useStreamKey_clicked();
+	void on_useAuth_toggled();
+
+private:
 	/* output */
 	void LoadSimpleOutputSettings();
 	void LoadAdvOutputStreamingSettings();
@@ -210,9 +250,9 @@ private:
 	void LoadAdvOutputRecordingEncoderProperties();
 	void LoadAdvOutputFFmpegSettings();
 	void LoadAdvOutputAudioSettings();
-	void SetAdvOutputFFmpegEnablement(
-		ff_codec_type encoderType, bool enabled,
-		bool enableEncode = false);
+	void SetAdvOutputFFmpegEnablement(ff_codec_type encoderType,
+					  bool enabled,
+					  bool enableEncode = false);
 
 	/* audio */
 	void LoadListValues(QComboBox *widget, obs_property_t *prop, int index);
@@ -244,13 +284,29 @@ private:
 
 	void RecalcOutputResPixels(const char *resText);
 
+	QIcon generalIcon;
+	QIcon streamIcon;
+	QIcon outputIcon;
+	QIcon audioIcon;
+	QIcon videoIcon;
+	QIcon hotkeysIcon;
+	QIcon advancedIcon;
+
+	QIcon GetGeneralIcon() const;
+	QIcon GetStreamIcon() const;
+	QIcon GetOutputIcon() const;
+	QIcon GetAudioIcon() const;
+	QIcon GetVideoIcon() const;
+	QIcon GetHotkeysIcon() const;
+	QIcon GetAdvancedIcon() const;
+
 private slots:
 	void on_theme_activated(int idx);
 
 	void on_listWidget_itemSelectionChanged();
 	void on_buttonBox_clicked(QAbstractButton *button);
 
-	void on_streamType_currentIndexChanged(int idx);
+	void on_service_currentIndexChanged(int idx);
 	void on_simpleOutputBrowse_clicked();
 	void on_advOutRecPathBrowse_clicked();
 	void on_advOutFFPathBrowse_clicked();
@@ -274,13 +330,15 @@ private slots:
 	void AudioChanged();
 	void AudioChangedRestart();
 	void ReloadAudioSources();
+	void SurroundWarning(int idx);
+	void SpeakerLayoutChanged(int idx);
 	void OutputsChanged();
 	void Stream1Changed();
 	void VideoChanged();
 	void VideoChangedResolution();
 	void VideoChangedRestart();
 	void HotkeysChanged();
-	void ReloadHotkeys(obs_hotkey_id ignoreKey=OBS_INVALID_HOTKEY_ID);
+	void ReloadHotkeys(obs_hotkey_id ignoreKey = OBS_INVALID_HOTKEY_ID);
 	void AdvancedChanged();
 	void AdvancedChangedRestart();
 
@@ -295,9 +353,20 @@ private slots:
 	void SimpleRecordingQualityLosslessWarning(int idx);
 
 	void SimpleReplayBufferChanged();
+	void AdvReplayBufferChanged();
 
 	void SimpleStreamingEncoderChanged();
 
+	OBSService SpawnTempService();
+
+	void SetGeneralIcon(const QIcon &icon);
+	void SetStreamIcon(const QIcon &icon);
+	void SetOutputIcon(const QIcon &icon);
+	void SetAudioIcon(const QIcon &icon);
+	void SetVideoIcon(const QIcon &icon);
+	void SetHotkeysIcon(const QIcon &icon);
+	void SetAdvancedIcon(const QIcon &icon);
+
 protected:
 	virtual void closeEvent(QCloseEvent *event);
 
